# 래블업 개인정보처리방침 (한국어)

래블업 주식회사(이하 “회사”라 합니다)는 정보통신망 이용촉진 및 정보보호 등에 관한 법률, 개인정보보호법, 통신비밀보호법, 전기통신사업법 등 정보통신서비스 제공자가 준수하여야 할 관련 법령상의 개인정보보호규정을 준수하며, 관련 법령에 의거한 개인정보처리방침을 정하여 이용자 권익 보호에 최선을 다하고 있습니다. 본 개인정보처리방침은 회사에서 제공하는 서비스에 적용되며 다음과 같은 내용을 담고 있습니다.

## 제1장 수집하는 개인정보의 항목 및 수집방법

### 제1조 (수집하는 개인정보의 항목)

1. 회사는 회원가입, 원활한 이용자상담, 각종 서비스의 제공 등을 위해 아래와 같은 최소한의 개인정보를 이용자로부터 수집하고 있습니다.

   1. 회원가입
      - 성명, 이메일계정, 비밀번호
   2. 결제 수단 등록
      - 휴대전화 번호, 주소, 소속, 생년월일(사업자의 경우 사업자등록번호), 신용카드번호, 카드 유효기간

2. 서비스 이용과정이나 서비스 제공 업무 처리 과정에서 아래와 같은 정보들이 자동으로 생성되거나 추가로 수집될 수 있습니다.

   - IP Address, 쿠키, 접속 로그, 방문 일시, 서비스 이용 기록 및 서비스 이용 산출물(프로그램 코드 등), 불량 이용 기록, 결제 기록

### 제2조 (개인정보 수집방법)

1. 회사는 다음과 같은 방법으로 개인정보를 수집합니다.
   1. 홈페이지 수집
   2. 생성 정보 수집 툴을 통한 수집
   3. 이미 이용자로부터 개인정보 처리에 관하여 동의를 받은 제3자로부터 제공받는 개인정보의 수집(단, 이용자가 해당 제3자의 서비스를 통해 회사 홈페이지에 로그인하는 경우에 한함)

## 제2장 개인정보의 수집 및 이용목적

### 제3조 (서비스 제공에 관한 계약 이행 및 서비스 제공에 따른 요금정산)

회사는 콘텐츠 제공, 특정 맞춤 서비스 제공, 물품배송 또는 청구서 등 발송, 본인인증, 구매 및 요금 결제, 요금 추심 등 서비스 제공에 관련한 목적으로 이용자의 개인정보를 수집합니다.

### 제4조 (회원관리)

회사는 회원제 서비스 이용 및 제한적 본인 확인제에 따른 본인확인, 개인식별, 불량회원의 부정 이용 방지와 비인가 사용방지, 가입의사 확인, 가입 및 가입횟수 제한, 추후 법정 대리인 본인확인, 분쟁 조정을 위한 기록보존, 불만처리 등 민원처리, 고지사항 전달 등 회원관리와 관련된 목적으로 이용자의 개인정보를 수집합니다.

### 제5조 (신규 서비스 개발 및 마케팅광고에의 활용)

회사는 신규 서비스 개발 및 맞춤 서비스 제공, 통계학적 특성에 따른 서비스 제공 및 광고 게재, 서비스의 유효성 확인, 이벤트 및 광고성 정보 제공 및 참여기회 제공, 접속빈도 파악, 회원의 서비스 이용에 대한 통계 등 신규 서비스 개발과 마케팅 활용에 관련된 목적으로 이용자의 개인정보를 수집합니다.

## 제3장 개인정보의 제공 및 처리 위탁

### 제6조 (개인정보의 제공)

회사는 이용자들의 개인정보를 제2장에서 고지한 범위 내에서 사용하며, 이용자의 사전 동의 없이는 동 범위를 초과하여 이용하거나 원칙적으로 이용자의 개인정보를 외부에 공개하지 않습니다. 다만, 아래의 경우에는 예외로 합니다.

1. 이용자들이 사전에 동의한 경우
2. 법령의 규정에 의거하거나, 수사 목적으로 법령에 정해진 절차와 방법에 따라 수사기관의 요구가 있는 경우
3. 이용자 사전 동의 후 개인정보 제공이 발생하는 경우

제공받는 자 | 제공받는 자의 이용목적 | 제공하는 개인정보 | 보유 및 이용기간
--- | --- | --- | ---
한국정보통신기술협회 | 클라우드 서비스 제공 시험/인증 업무 처리, 서비스 장애 해결 등 민원 처리 | 성명, 이메일계정, 휴대전화 번호, 서비스 이용 기록 | 이용자의 동의일로부터 회사의 클로즈드 베타 서비스 종료시까지

### 제7조 (개인정보의 처리위탁)

1. 회사는 서비스 향상을 위해서 아래와 같이 개인정보를 위탁하고 있으며, 관계 법령에 따라 위탁계약 시 개인정보가 안전하게 관리될 수 있도록 필요한 사항을 규정하고 있습니다.
2. 회사의 개인정보 위탁처리 기관 및 위탁업무내용은 아래와 같습니다.

수탁업체 | 위탁업무의 내용 | 개인정보의 보유 및 이용기간
--- | --- | ---
(주)KG이니시스, (주)시옷 | 결제처리(휴대폰, 무통장 입금, 계좌이체, 신용카드, 지류상품권 및 기타 결제수단, 환불계좌 인증) 및 결제도용 방지 | 회원 탈퇴시 혹은 위탁 계약 종료시까지

## 제4장 개인정보의 보유 및 이용기간

개인정보의 보유 및 이용기간 이용자자의 개인정보는 원칙적으로 개인정보의 수집 및 이용목적이 달성되면 지체 없이 파기합니다. 단, 다음의 정보에 대해서는 아래의 이유로 명시한 기간 동안 보존합니다.

### 제8조 (회사 내부 방침에 의한 정보 보유 사유)

보관하는 정보 | 보존 이유 | 보존 기간
--- | --- | ---
부정이용 기록 | 부정이용 방지 | 1년
문의/제휴 내용 (이용자에게 별도의 동의를 구한 경우) | 이용자 상담 처리 | 6개월

### 제9조 (관련 법령에 의한 정보 보유 사유)

상법, 전자상거래 등에서의 소비자보호에 관한 법률 등 관련 법령의 규정에 의하여 보존할 필요가 있는 경우 회사는 관련 법령에서 정한 일정한 기간 동안 회원정보를 보관합니다. 이 경우 회사는 보관하는 정보를 그 보관의 목적으로만 이용하며 보존기간은 아래의 예시와 같습니다.

보관하는 정보 | 보존 이유 | 보존 기간
--- | --- | ---
계약 또는 청약철회 등에 관한 기록 | 전자상거래 등에서의 소비자보호에 관한 법률 | 5년
대금결제 및 재화 등의 공급에 관한 기록 | 전자상거래 등에서의 소비자보호에 관한 법률 | 5년
소비자의 불만 또는 분쟁 처리에 관한 기록 | 전자상거래 등에서의 소비자보호에 관한 법률 | 3년
표시/광고에 관한 기록 | 전자상거래 등에서의 소비자보호에 관한 법률 | 6개월
세법이 규정하는 모든 거래에 관한 장부 및 증빙서류 | 국세기본법, 법인세법 | 5년
전자금융 거래에 관한 기록 | 전자금융거래법 | 5년
로그인 기록 | 통신비밀보호법 | 3개월

## 제5장 개인정보 파기절차 및 방법

개인정보 파기절차 및 방법 이용자의 개인정보는 원칙적으로 개인정보의 수집 및 이용목적이 달성되면 지체 없이 파기합니다. 회사의 개인정보 파기절차 및 방법은 다음과 같습니다.

### 제10조 (파기절차)

1. 이용자가 회원가입 등을 위해 입력한 정보는 목적이 달성된 후 별도의 DB 로 옮겨져(종이의 경우 별도의 서류함) 내부 방침 및 기타 관련 법령에 의한 정보보호 사유에 따라(보유 및 이용기간 참조) 일정 기간 저장된 후 파기됩니다.
2. 동 개인정보는 법률에 의한 경우를 제외하고 보유되는 이외의 다른 목적으로 이용되지 않습니다.

### 제11조 (파기방법)

1. 종이에 출력된 개인정보는 분쇄기로 분쇄하거나 소각을 통하여 파기합니다.
2. 전자적 파일 형태로 저장된 개인정보는 기록을 재생할 수 없는 기술적 방법을 사용하여 삭제합니다.

## 제6장 이용자 및 법정대리인의 권리

### 제12조 (권리 및 행사방법)

1. 이용자 및 법정대리인은 언제든지 등록되어 있는 자신의 개인정보를 조회, 수정 또는 가입해지를 요청할 수 있습니다.
2. 이용자의 개인정보 조회, 수정 또는 가입해지(동의철회)를 위해서는 회사 홈페이지의 관련 페이지에서 본인 확인 절차를 거친 후 직접 열람, 정정 또는 탈퇴가 가능합니다.
3. 이용자는 회사의 개인정보보호책임자 혹은 담당자에게 서면, 전화 또는 이메일로 연락하여 본 조의 권리를 행사하실 수 있습니다.
4. 이용자가 개인정보의 오류에 대한 정정을 요청하신 경우에는 정정을 완료하기 전까지 당해 개인정보를 이용 또는 제공하지 않습니다. 또한 잘못된 개인정보를 제3자에게 이미 제공한 경우에는 정정 처리결과를 제3자에게 지체없이 통지하여 정정이 이루어지도록 하겠습니다.
5. 회사는 이용자 혹은 법정 대리인의 요청에 의해 해지 또는 삭제된 개인정보는 제4장에 명시된 바에 따라 처리하고 그 외의 용도로 열람 또는 이용할 수 없도록 처리하고 있습니다.

## 제7장 개인정보 자동 수집 장치의 설치/운영 및 거부에 관한 사항

### 제13조 (쿠키의 정의)

1. 회사는 개인화되고 맞춤화 된 서비스를 제공하기 위해서 이용자의 정보를 저장하고 수시로 불러오는 ‘쿠키(cookie)’를 사용합니다.
2. 쿠키는 웹사이트를 운영하는데 이용되는 서버가 이용자의 브라우저에게 보내는 아주 작은 텍스트 파일로 이용자 컴퓨터의 하드디스크에 저장됩니다. 이후 이용자가 웹 사이트에 방문할 경우 웹 사이트 서버는 이용자의 하드 디스크에 저장되어 있는 쿠키의 내용을 읽어 이용자의 환경설정을 유지하고 맞춤화된 서비스를 제공하기 위해 이용됩니다.
3. 쿠키는 개인을 식별하는 정보를 자동적/능동적으로 수집하지 않으며, 이용자는 언제든지 이러한 쿠키의 저장을 거부하거나 삭제할 수 있습니다.

### 제14조 (쿠키의 사용 목적)

이용자들이 방문한 회사의 각 서비스와 웹 사이트들에 대한 방문 및 이용형태, 인기 검색어, 이용자 규모 등을 파악하여 이용자에게 광고를 포함한 최적화된 맞춤형 정보를 제공을 위해 사용합니다.

### 제15조 (쿠키의 설치/운영 및 거부)

1. 이용자는 쿠키 설치에 대한 선택권을 가지고 있습니다. 따라서 이용자는 웹브라우저에서 옵션을 설정함으로써 모든 쿠키를 허용하거나, 쿠키가 저장될 때마다 확인을 거치거나, 아니면 모든 쿠키의 저장을 거부할 수도 있습니다.
2. 다만, 쿠키의 저장을 거부할 경우에는 로그인이 필요한 회사의 일부 서비스는 이용에 어려움이 있을 수 있습니다.

## 제8장 개인정보의 기술적/관리적 및 물리적 보호 대책

회사는 이용자들의 개인정보를 처리함에 있어 개인정보가 분실, 도난, 누출, 변조 또는 훼손되지 않도록 안전성 확보를 위하여 다음과 같은 기술적/관리적 및 물리적 보호 대책을 강구하고 있습니다.

### 제16조 (내부 관리계획의 수립 및 시행)

회사는 개인정보의 안전한 처리를 위하여 개인정보의 보호 등 제반 사항에 관한 내부 관리계획을 수립하고 이를 시행하고 있습니다.

### 제17조 (비밀번호 암호화)

회원 비밀번호는 암호화되어 저장 및 관리되고 있어 본인만이 알고 있으며, 개인정보의 확인 및 변경도 비밀번호를 알고 있는 본인에 의해서만 가능합니다.

### 제18조 (해킹 등에 대비한 대책)

회사는 해킹이나 컴퓨터 바이러스 등에 의해 회원의 개인정보가 유출되거나 훼손되는 것을 막기 위해 최선을 다하고 있습니다. 개인정보의 훼손에 대비해서 자료를 수시로 백업하고 있고, 최신 백신프로그램을 이용하여 이용자들의 개인정보나 자료가 누출되거나 손상되지 않도록 방지하고 있으며, 암호화 통신 등을 통하여 네트워크상에서 개인정보를 안전하게 전송할 수 있도록 하고 있습니다. 그리고 침입차단시스템을 이용하여 외부로부터의 무단 접근을 통제하고 있으며, 기타 시스템적으로 보안성을 확보하기 위한 가능한 모든 기술적 장치를 갖추려 노력하고 있습니다.

### 제19조 (침해사고 대응을 위한 접속기록의 보관 등 조치)

회사는 개인정보 침해사고가 발생하지 않도록 최선을 다하고 있습니다. 또한 침해사고 발생에 대응하기 위하여 개인정보 보관 시스템에 접속한 기록을 최소 6개월 이상 보관 및 관리하고 있으며, 그 기록이 위조 또는 변조되지 않도록 하는 기술적 조치를 마련하고 있습니다.

### 20조 (개인정보 처리 직원의 최소화 및 교육)

회사의 개인정보관련 처리 직원은 담당자에 한정하고 있고 이를 위한 별도의 비밀번호를 부여하여 정기적으로 갱신하고 있으며, 담당자에 대한 수시 교육을 통하여 개인정보처리방침의 준수를 항상 강조하고 있습니다.

### 제21조 (개인정보보호전담기구의 운영)

사내 개인정보보호전담기구 등을 통하여 개인정보처리방침의 이행사항 및 담당자의 준수 여부를 확인하여 문제가 발견될 경우 즉시 수정하고 바로잡을 수 있도록 노력하고 있습니다. 단, 회사가 개인정보보호 의무를 다하였음에도 불구하고 이용자 본인의 부주의나 회사가 관리하지 않는 영역에서의 사고 등 회사의 귀책에 기인하지 않은 손해에 대해서는 회사는 책임을 지지 않습니다.

## 제9장 기타

### 제22조 (개인정보보호책임자 및 담당자의 연락처)

귀하께서는 회사의 서비스를 이용하시며 발생하는 모든 개인정보보호 관련 민원을 개인정보보호책임자 혹은 담당부서로 신고하실 수 있습니다. 회사는 이용자들의 신고사항에 대해 신속하게 충분한 답변을 드릴 것입니다.

직책 | 개인정보보호책임자 | 직책 | 개인정보보호담당자
--- | --- | --- | ---
이름 | 신정규 | 이름 | 양정승
소속 | 래블업 주식회사 | 소속 | 래블업 주식회사
전화 | 070-8200-2587 | 전화 | 070-8200-2587
이메일 | contact@lablup.com | 이메일 | jsyang@lablup.com

### 제23조 (예외 사항)

회사의 인터넷 서비스에 링크되어 있는 웹사이트들이 개인정보를 수집하는 행위에 대해서는 본 개인정보처리방침이 적용되지 않음을 알려 드립니다.

### 제24조 (고지의 의무)

현 개인정보처리방침의 내용에 추가, 삭제 및 수정이 있을 시에는 개정 최소 7일 전부터 회사 홈페이지를 통해 고지할 것입니다. 다만, 개인정보의 수집 및 활용, 제3자 제공 등과 같이 이용자 권리의 중요한 변경이 있을 경우에는 최소 30일 전에 고지합니다.

## 부칙

본 개인정보처리방침은 2019년 8월 16일로부터 시행됩니다.